/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizaccessrecord.param;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;
import lombok.Setter;

import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 门禁记录表编辑参数
 *
 * @author fanzherong
 * @date  2025/03/25 16:48
 **/
@Getter
@Setter
public class BizAccessRecordEditParam {

    /** 主键id */
    @Schema(description = "主键id", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 车牌号码 */
    @Schema(description = "车牌号码")
    private String licensePlate;

    /** 车牌颜色 */
    @Schema(description = "车牌颜色")
    private String licensePlateColor;

    /** 进出时间 */
    @Schema(description = "进出时间")
    private String inOutTime;

    /** 车牌图片 */
    @Schema(description = "车牌图片")
    private String licensePlatePicture;

    /** 车图片 */
    @Schema(description = "车图片")
    private String carPicture;

    /** 进出类型  1-进厂  2-出厂 */
    @Schema(description = "进出类型  1-进厂  2-出厂")
    private String inOutFactory;

    /** 车辆类型 */
    @Schema(description = "车辆类型")
    private String vehicleType;

    /** 地磅绑定状态 0-未绑定 1-单次过磅完成 2-一次过磅完成  3-二次过磅完成  4-已结束 */
    @Schema(description = "地磅绑定状态 0-未绑定 1-单次过磅完成 2-一次过磅完成  3-二次过磅完成  4-已结束")
    private String bindStatus;

    /** 预约ID */
    @Schema(description = "预约ID")
    private String appointmentRegisterId;

    /** 订单id */
    @Schema(description = "订单id")
    private String orderId;

    /** 云端车牌图片 */
    @Schema(description = "云端车牌图片")
    private String cloudPlateName;

    /** 云端车图片 */
    @Schema(description = "云端车图片")
    private String cloudLicenseName;

    /** 云端抓拍1 */
    @Schema(description = "云端抓拍1")
    private String cloudCapturePic1;

    /** 云端抓拍2 */
    @Schema(description = "云端抓拍2")
    private String cloudCapturePic2;

    /** 云端抓拍3 */
    @Schema(description = "云端抓拍3")
    private String cloudCapturePic3;

    /** 云端抓拍4 */
    @Schema(description = "云端抓拍4")
    private String cloudCapturePic4;

    /** 云端抓拍5 */
    @Schema(description = "云端抓拍5")
    private String cloudCapturePic5;

    /** 放行形式  1-自动放行  2-人工放行 */
    @Schema(description = "放行形式  1-自动放行  2-人工放行")
    private Integer releaseType;

    /** 所属设备分类 1-门禁端设备 2-签样区设备 */
    @Schema(description = "所属设备分类 1-门禁端设备 2-签样区设备")
    private Boolean weighbridgeType;

    /** 设备组（1：一组，2：二组） */
    @Schema(description = "设备组（1：一组，2：二组）")
    private Boolean deviceGroup;

    /** 抓拍1 */
    @Schema(description = "抓拍1")
    private String capturePic1;

    /** 抓拍2 */
    @Schema(description = "抓拍2")
    private String capturePic2;

    /** 抓拍3 */
    @Schema(description = "抓拍3")
    private String capturePic3;

    /** 抓拍4 */
    @Schema(description = "抓拍4")
    private String capturePic4;

    /** 抓拍5 */
    @Schema(description = "抓拍5")
    private String capturePic5;

    /** 推送状态（0-推送失败 1-推送成功） */
    @Schema(description = "推送状态（0-推送失败 1-推送成功）")
    private Integer pushStatus;

}
