/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizvehicle.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizvehicle.entity.BizVehicle;
import vip.xiaonuo.biz.modular.bizvehicle.param.BizVehicleAddParam;
import vip.xiaonuo.biz.modular.bizvehicle.param.BizVehicleEditParam;
import vip.xiaonuo.biz.modular.bizvehicle.param.BizVehicleIdParam;
import vip.xiaonuo.biz.modular.bizvehicle.param.BizVehiclePageParam;
import vip.xiaonuo.biz.modular.bizvehicle.service.BizVehicleService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 车辆信息控制器
 *
 * @author fanzherong
 * @date  2025/04/08 09:26
 */
@Tag(name = "车辆信息控制器")
@RestController
@Validated
public class BizVehicleController {

    @Resource
    private BizVehicleService bizVehicleService;

    /**
     * 获取车辆信息分页
     *
     * @author fanzherong
     * @date  2025/04/08 09:26
     */
    @Operation(summary = "获取车辆信息分页")
    @SaCheckPermission("/biz/bizvehicle/page")
    @GetMapping("/biz/bizvehicle/page")
    public CommonResult<Page<BizVehicle>> page(BizVehiclePageParam bizVehiclePageParam) {
        return CommonResult.data(bizVehicleService.page(bizVehiclePageParam));
    }

    /**
     * 添加车辆信息
     *
     * @author fanzherong
     * @date  2025/04/08 09:26
     */
    @Operation(summary = "添加车辆信息")
    @CommonLog("添加车辆信息")
    @PostMapping("/biz/bizvehicle/add")
    public CommonResult<String> add(@RequestBody @Valid BizVehicleAddParam bizVehicleAddParam) {
        bizVehicleService.add(bizVehicleAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑车辆信息
     *
     * @author fanzherong
     * @date  2025/04/08 09:26
     */
    @Operation(summary = "编辑车辆信息")
    @CommonLog("编辑车辆信息")
    @PostMapping("/biz/bizvehicle/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizVehicleEditParam bizVehicleEditParam) {
        bizVehicleService.edit(bizVehicleEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除车辆信息
     *
     * @author fanzherong
     * @date  2025/04/08 09:26
     */
    @Operation(summary = "删除车辆信息")
    @CommonLog("删除车辆信息")
    @PostMapping("/biz/bizvehicle/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizVehicleIdParam> bizVehicleIdParamList) {
        bizVehicleService.delete(bizVehicleIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取车辆信息详情
     *
     * @author fanzherong
     * @date  2025/04/08 09:26
     */
    @Operation(summary = "获取车辆信息详情")
    @GetMapping("/biz/bizvehicle/detail")
    public CommonResult<BizVehicle> detail(@Valid BizVehicleIdParam bizVehicleIdParam) {
        return CommonResult.data(bizVehicleService.detail(bizVehicleIdParam));
    }
}
