/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.transportcompany.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.transportcompany.entity.BizTransportCompany;
import vip.xiaonuo.biz.modular.transportcompany.mapper.BizTransportCompanyMapper;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyAddParam;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyEditParam;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyIdParam;
import vip.xiaonuo.biz.modular.transportcompany.param.BizTransportCompanyPageParam;
import vip.xiaonuo.biz.modular.transportcompany.service.BizTransportCompanyService;

import java.util.List;

/**
 * 运输单位Service接口实现类
 *
 * @author 徐超
 * @date  2025/01/02 17:46
 **/
@Service
public class BizTransportCompanyServiceImpl extends ServiceImpl<BizTransportCompanyMapper, BizTransportCompany> implements BizTransportCompanyService {

    @Override
    public Page<BizTransportCompany> page(BizTransportCompanyPageParam bizTransportCompanyPageParam) {
        QueryWrapper<BizTransportCompany> queryWrapper = new QueryWrapper<BizTransportCompany>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizTransportCompanyPageParam.getName())) {
            queryWrapper.lambda().like(BizTransportCompany::getName, bizTransportCompanyPageParam.getName());
        }
        if(ObjectUtil.isAllNotEmpty(bizTransportCompanyPageParam.getSortField(), bizTransportCompanyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizTransportCompanyPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizTransportCompanyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizTransportCompanyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizTransportCompany::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizTransportCompanyAddParam bizTransportCompanyAddParam) {
        BizTransportCompany bizTransportCompany = BeanUtil.toBean(bizTransportCompanyAddParam, BizTransportCompany.class);
        this.save(bizTransportCompany);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizTransportCompanyEditParam bizTransportCompanyEditParam) {
        BizTransportCompany bizTransportCompany = this.queryEntity(bizTransportCompanyEditParam.getId());
        BeanUtil.copyProperties(bizTransportCompanyEditParam, bizTransportCompany);
        this.updateById(bizTransportCompany);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizTransportCompanyIdParam> bizTransportCompanyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizTransportCompanyIdParamList, BizTransportCompanyIdParam::getId));
    }

    @Override
    public BizTransportCompany detail(BizTransportCompanyIdParam bizTransportCompanyIdParam) {
        return this.queryEntity(bizTransportCompanyIdParam.getId());
    }

    @Override
    public BizTransportCompany queryEntity(String id) {
        BizTransportCompany bizTransportCompany = this.getById(id);
        if(ObjectUtil.isEmpty(bizTransportCompany)) {
            throw new CommonException("运输单位不存在，id值为：{}", id);
        }
        return bizTransportCompany;
    }
}
